/*
        reader.cpp
        Mar. 21st, 2006
        Joris Roos <jorisr@gmx.de>
        Reads tokens/ASCII from a file
*/

#include "tokenreader.h"

char prog[8], comment[42], prot;
char* tokenfile;

int loadTokenFile(const char* file)
{
    int type = -1;
    /* 0 : TI-83
       1 : TI-83+
    */ 
    
    FILE* fh = fopen(file, "rb");
    
    if (fh == 0) return ERROR(FAILED, "could not open file '%s'.", file);
    
    char header[9]; /* this variable will, after the header was read, also be used
                       to store other temporary values that need to be checked
                       for correctness */ 
    header[8] = 0;  /* to make the strcmp's possible */
    short int data_size;
    char prot;
    
    /* read header and determine file type */
    fread(header, 8, 1, fh);
    if (!strcmp(header, "**TI83**")) type = 0;
    else if (!strcmp(header, "**TI83F*")) type = 1;
    else 
        return ERROR(FAILED, "invalid file type (TI-83 and TI-83+/TI-84+ files accepted).");
    
    /* check the rest of the header */
    fread(header, 3, 1, fh);
    if (header[0] != 0x1A || header[1] != 0x0A || header[2] != 0x00)
        return ERROR(FAILED, "invalid file type, missing 0x1A 0x0A 0x00.");
    
    /* read comment */
    fread(comment, 42, 1, fh);    
    
    /* size of data part, but this available later in the file, too, so
       this is just stored to the temporary buffer header */
    fread(header, 2, 1, fh);

    /* read size of variable header, needs to be 
       0x0B for TI-83 and
       0x0D for TI-83+ */
    fread(header, 2, 1, fh);
    if (!(header[0] == 0x0B || (type == 1 && header[0] == 0x0D)) || header[1] != 0x00)
        return ERROR(FAILED, "invalid file type.");
    
    /* now it's time to read the size of the data part */
    fread(&data_size, 1, 2, fh);
    
    /* read the protection status of the program */
    fread(&prot, 1, 1, fh);
    
    /* read name of the program; if TI-83+, read 2 extra bytes */
    fread(prog, 8, 1, fh);
    if (type == 1) fread(header, 2, 1, fh);
    
    /* read first 4 bytes of data part 
       (they do not contain any token information) */
    fread(header, 4, 1, fh);
    data_size -= 2;
    
    /* read in data part into buffer tokbuf,
       size is stored in tokbuf_l */
    char* tmp;
    int cc;
    freeTokBuf();
    tokbuf = (char*)malloc(data_size+1); /* this allocates one byte more than
                                            necessary, so there are no critical
                                            exceptions later when the table is
                                            searched (see writer.cpp) */
    if (tokbuf == 0) ERROR(ERR_DIE, "insufficient memory.");
    for (; data_size > 0; data_size--) {
        cc = fgetc(fh);
        if (cc == EOF) {
            ERROR(ERR_RESUME, "unexpected file end.");
            break;
        }
        tokbuf[tokbuf_l++] = (char)cc;
    }
    
    fclose(fh);
    
    /* copy file name of program to a global variable, so it can be
       read during the ASCII writing process (see writer.cpp) */
    tokenfile = (char*)malloc(strlen(file)+1);
    if (tokenfile == 0) ERROR(ERR_DIE, "insufficient memory.");
    strcpy(tokenfile, file);
    
    return 1;
}

/* Last Edit: Mar. 25th, 2006 */
