/*
        tokens.cpp
        Mar. 21st, 2006
        Joris Roos <jorisr@gmx.de>
        The TI-83/TI-83+ Tokens
*/

#include "tokenreader.h"

/*
    This table is by no means completely mature.
    There are still some tokens where I'm still looking for
    an appropriate ASCII representation. 
    
    Notes in brackets:
        (*)     -       The ASCII representation is not final.
        (?)     -       The ASCII representation might be wrong.
        (??)    -       This token might be wrong.
        (!)     -       The ASCII representation of this token is the same
                        as the ASCII representation of at least one other token.
*/

struct TABLE_ENTRY tokens[] = {
    ">DMS",        0x01, 0xFF,             // tToDMS
    ">DEC",        0x02, 0xFF,             // tToDEC
    ">Abc",        0x03, 0xFF,             // tToAbc (?)
    "->",          0x04, 0xFF,             // tStore
    "[",            0x06, 0xFF,            // tLBrack
    "]",            0x07, 0xFF,            // tRBrack
    "{",            0x08, 0xFF,            // tLBrace
    "}",            0x09, 0xFF,            // tRBrace
    "FromRad",      0x0A, 0xFF,            // tFromRad (*)
    "FromDeg",      0x0B, 0xFF,            // tFromDeg (*)
    "^-1",          0x0C, 0xFF,            // tRecip
    "",            0x0D, 0xFF,            // tSqr
    "Ltranspose",   0x0E, 0xFF,            // tTrnspos (*)
    "",            0x0F, 0xFF,            // tCube
    "(",            0x10, 0xFF,            // tLParen
    ")",            0x11, 0xFF,            // tRParen
    "round(",       0x12, 0xFF,            // tRound
    "pxl-Test(",    0x13, 0xFF,            // tPxTst
    "augment(",     0x14, 0xFF,            // tAug
    "rowSwap(",     0x15, 0xFF,            // tRowSwap
    "row+(",        0x16, 0xFF,            // tRowPlus
    "*row(",        0x17, 0xFF,            // tmRow
    "*row+(",       0x18, 0xFF,            // tmRowPlus
    "max(",         0x19, 0xFF,            // tMax
    "min(",         0x1A, 0xFF,            // tMin
    "R>Pr(",        0x1B, 0xFF,            // tRToPr
    "R>P(",        0x1C, 0xFF,            // tRToPo
    "R>Po(",        0x1C, 0xFF,            // tRToPo
    "P>Rx(",        0x1D, 0xFF,            // tPToRx
    "P>Ry(",        0x1E, 0xFF,            // tPToRy
    "median(",      0x1F, 0xFF,            // tMedian
    "randM(",       0x20, 0xFF,            // tRandM
    "mean(",        0x21, 0xFF,            // tMean
    "ROOT",         0x22, 0xFF,            // tRoot (*)
    "seq(",         0x23, 0xFF,            // tSeries (?)
    "fnInt(",       0x24, 0xFF,            // tFnInt
    "nDeriv(",      0x25, 0xFF,            // tNDeriv
    "evalF(",       0x26, 0xFF,            // tEvalF (*)
    "fMin(",        0x27, 0xFF,            // tFMin
    "fMax(",        0x28, 0xFF,            // tFMax
    " ",            0x29, 0xFF,            // tSpace
    "\"",           0x2A, 0xFF,            // tString
    ",",            0x2B, 0xFF,            // tComma
    "ii",           0x2C, 0xFF,            // tii
    "!",            0x2D, 0xFF,            // tFact
    "CubicReg ",    0x2E, 0xFF,            // tCubicR (?)
    "QuartReg ",    0x2F, 0xFF,            // tQuartR (?)
    /* 0x30 - 0x39 are tokens for the digits 0-9,
       they are the same in ASCII, thus entries
       are not necessary */
    ".",            0x3A, 0xFF,            // tDecPt (?)
    "ee",           0x3B, 0xFF,            // tee
    " or ",         0x3C, 0xFF,            // tOr
    " xor ",        0x3D, 0xFF,            // tXor
    ":",            0x3E, 0xFF,            // tColon (!)
    "\n",           0x3F, 0xFF,            // tEnter
    " and ",        0x40, 0xFF,            // tAnd
    /* 0x41 - 0x5A are tokens for the letters A-Z,
       they are the same in ASCII, thus entries
       are not necessary */
    "",            0x5B, 0xFF,            // tTheta
    
    "[A]",          0x5C, 0x00,         // tMatA
    "[B]",          0x5C, 0x01,         // tMatB
    "[C]",          0x5C, 0x02,         // tMatC
    "[D]",          0x5C, 0x03,         // tMatD
    "[E]",          0x5C, 0x04,         // tMatE
    "[F]",          0x5C, 0x05,         // tMatF
    "[G]",          0x5C, 0x06,         // tMatG
    "[H]",          0x5C, 0x07,         // tMatH
    "[I]",          0x5C, 0x08,         // tMatI
    "[J]",          0x5C, 0x09,         // tMatJ
    
    "L1",           0x5D, 0x00,         // tL1
    "L2",           0x5D, 0x01,         // tL2
    "L3",           0x5D, 0x02,         // tL3
    "L4",           0x5D, 0x03,         // tL4
    "L5",           0x5D, 0x04,         // tL5
    "L6",           0x5D, 0x05,         // tL6
    
    "Y1",           0x5E, 0x10,         // tY1
    "Y2",           0x5E, 0x11,         // tY2
    "Y3",           0x5E, 0x12,         // tY3
    "Y4",           0x5E, 0x13,         // tY4
    "Y5",           0x5E, 0x14,         // tY5
    "Y6",           0x5E, 0x15,         // tY6
    "Y7",           0x5E, 0x16,         // tY7
    "Y8",           0x5E, 0x17,         // tY8
    "Y9",           0x5E, 0x18,         // tY9
    "Y0",           0x5E, 0x19,         // tY0
    
    "X1t",          0x5E, 0x20,         // tX1T
    "Y1t",          0x5E, 0x21,         // tY1T
    "X2t",          0x5E, 0x22,         // tX2T
    "Y2t",          0x5E, 0x23,         // tY2T
    "X3t",          0x5E, 0x24,         // tX3T
    "Y3t",          0x5E, 0x25,         // tY3T
    "X4t",          0x5E, 0x26,         // tX4T
    "Y4t",          0x5E, 0x27,         // tY4T
    "X5t",          0x5E, 0x28,         // tX5T
    "Y5t",          0x5E, 0x29,         // tY5T
    "X6t",          0x5E, 0x2A,         // tX6T
    "Y6t",          0x5E, 0x2B,         // tY6T
    
    "R1",           0x5E, 0x40,         // tR1
    "R2",           0x5E, 0x41,         // tR2
    "R3",           0x5E, 0x42,         // tR3
    "R4",           0x5E, 0x43,         // tR4
    "R5",           0x5E, 0x44,         // tR5
    "R6",           0x5E, 0x45,         // tR6
    
    "Un",           0x5E, 0x80,         // tun
    "Vn",           0x5E, 0x81,         // tvn
    "Wn",           0x5E, 0x82,         // twn
    
    "prgm",         0x5F, 0,            // tProg
    
    "Pic1",         0x60, 0x00,         // tPic1
    "Pic2",         0x60, 0x01,         // tPic2
    "Pic3",         0x60, 0x02,         // tPic3
    "Pic4",         0x60, 0x03,         // tPic4
    "Pic5",         0x60, 0x04,         // tPic5
    "Pic6",         0x60, 0x05,         // tPic6
    "Pic7",         0x60, 0x06,         // tPic7
    "Pic8",         0x60, 0x07,         // tPic8
    "Pic9",         0x60, 0x08,         // tPic9
    "Pic0",         0x60, 0x09,         // tPic0
    
    "GDB1",         0x61, 0x00,         // tGDB1
    "GDB2",         0x61, 0x01,         // tGDB2
    "GDB3",         0x61, 0x02,         // tGDB3
    "GDB4",         0x61, 0x03,         // tGDB4
    "GDB5",         0x61, 0x04,         // tGDB5
    "GDB6",         0x61, 0x05,         // tGDB6
    "GDB7",         0x61, 0x06,         // tGDB7
    "GDB8",         0x61, 0x07,         // tGDB8
    "GDB9",         0x61, 0x08,         // tGDB9
    "GDB0",         0x61, 0x09,         // tGDB0
    
    /* this is a 2-byte-token, however all the
       possible 2nd halfs for it are only for
       use by TI-OS, therefore, they are not implemented */ 
    "tVarOut",      0x62, 0xFE,         // tVarOut (*)
       
    "uXscl",        0x63, 0x00,         // tuXscl
    "uYscl",        0x63, 0x01,         // tuYscl
    "Xscl",         0x63, 0x02,         // tXscl
    "Yscl",         0x63, 0x03,         // tYscl
    /* 0x04 - 0x09 are internally used for recursive equations,
       not necessary to implement */ 
    "Xmin",         0x63, 0x0A,         // tXmin
    "Xmax",         0x63, 0x0B,         // tXmax
    "Ymin",         0x63, 0x0C,         // tYmin
    "Ymax",         0x63, 0x0D,         // tYmax
    "Tmin",         0x63, 0x0E,         // tTmin
    "Tmax",         0x63, 0x0F,         // tTmax
    "min",         0x63, 0x10,         // tThetaMin
    "max",         0x63, 0x11,         // tThetaMax
    "uXmin",        0x63, 0x12,         // tuXmin
    "uXmax",        0x63, 0x13,         // tuXmax
    "uYmin",        0x63, 0x14,         // tuYmin
    "uYmax",        0x63, 0x15,         // tuYmax
    "umin",        0x63, 0x16,         // tuThetMin
    "umax",        0x63, 0x17,         // tuThetMax
    "uTmin",        0x63, 0x18,         // tuTmin
    "uTmax",        0x63, 0x19,         // tuTmax
    "TblMin",       0x63, 0x1A,         // tTblMin
    "PlotStart",    0x63, 0x1B,         // tPlotStart
    "uPlotStart",   0x63, 0x1C,         // tuPlotStart
    "nMax",         0x63, 0x1D,         // tnMax
    "unMax",        0x63, 0x1E,         // tunMax
    "nMin",         0x63, 0x1F,         // tnMin
    "unMin",        0x63, 0x20,         // tunMin
    "TblStep",      0x63, 0x21,         // tTblStep
    "TStep",        0x63, 0x22,         // tTStep
    "Step",        0x63, 0x23,         // tThetaStep
    "uTStep",       0x63, 0x24,         // tuTStep
    "uStep",       0x63, 0x25,         // tuStep
    "DeltaX",       0x63, 0x26,         // tDeltaX
    "DeltaY",       0x63, 0x27,         // tDeltaY
    "XFact",        0x63, 0x28,         // tXFact
    "YFact",        0x63, 0x29,         // tYFact
    "TblInput",     0x63, 0x2A,         // tTblInput
    "FinN",         0x63, 0x2B,         // tFinN
    "FinI",         0x63, 0x2C,         // tFinI
    "FinPV",        0x63, 0x2D,         // tFinPV
    "FinPMT",       0x63, 0x2E,         // tFinPMT
    "FinFV",        0x63, 0x2F,         // tFinFV
    "FinPY",        0x63, 0x30,         // tFinPY
    "FinCY",        0x63, 0x31,         // tFinCY
        
    /* 0x32 - 0x35 are not implemented */
    "Xres",         0x63, 0x36,         // tXRes
    "uXres",        0x63, 0x37,         // tuXRes
    /* 0x38 - 0x3F are not implemented */
     
    "Radian",       0x64, 0xFF,            // tRad
    "Degree",       0x65, 0xFF,            // tDeg
    "Normal",       0x66, 0xFF,            // tNormF
    "Sci",          0x67, 0xFF,            // tSci
    "Eng",          0x68, 0xFF,            // tEng
    "Float",        0x69, 0xFF,            // tFloat
    "=",            0x6A, 0xFF,            // tEQ
    "<",            0x6B, 0xFF,            // tLT
    ">",            0x6C, 0xFF,            // tGT
    "<=",           0x6D, 0xFF,            // tLE
    ">=",           0x6E, 0xFF,            // tGE
    "!=",           0x6F, 0xFF,            // tNE
    "+",            0x70, 0xFF,            // tAdd
    "-",            0x71, 0xFF,            // tSub
    "Ans",          0x72, 0xFF,            // tAns
    "Fix ",         0x73, 0xFF,            // tFix
    "Horiz",        0x74, 0xFF,            // tSplitOn (?)
    "Full",         0x75, 0xFF,            // tFullScreen
    "Func",         0x76, 0xFF,            // tStndrd
    "Param",        0x77, 0xFF,            // tParam
    "Pol",          0x78, 0xFF,            // tPolar
    "Sequential",   0x79, 0xFF,            // tSeqG (?)
    "AFillOn",      0x7A, 0xFF,            // tAFillOn (*)
    "AFillOff",     0x7B, 0xFF,            // tAFillOff (*)
    "ACalcOn",      0x7C, 0xFF,            // tACalcOn (*)
    "ACalcOff",     0x7D, 0xFF,            // tACalcOff (*)
    "Seq",          0x7E, 0x00,         // tSeq
    "SeqG",         0x7E, 0x00,         // tSeq
    "Simul",        0x7E, 0x01,         // tSimulG
    "PolarGC",      0x7E, 0x02,         // tPolarG
    "RectGC",       0x7E, 0x03,         // tRectG
    "CoordOn",      0x7E, 0x04,         // tCoordOn
    "CoordOff",     0x7E, 0x05,         // tCoordOff
    "DrawLine",     0x7E, 0x06,         // tDrawLine (*)
    "DrawDot",      0x7E, 0x07,         // tDrawDot (*)
    "AxesOn",       0x7E, 0x08,         // tAxisOn
    "AxesOff",      0x7E, 0x09,         // tAxisOff
    "GridOn",       0x7E, 0x0A,         // tGridOn
    "GridOff",      0x7E, 0x0B,         // tGridOff
    "LabelOn",      0x7E, 0x0C,         // tLblOn
    "LabelOff",     0x7E, 0x0D,         // tLblOff
    "WebOn",        0x7E, 0x0E,         // tWebOn
    "WebOff",       0x7E, 0x0F,         // tWebOff
    "uvAxes",       0x7E, 0x10,         // tuv
    "vwAxes",       0x7E, 0x11,         // tvw
    "uwAxes",       0x7E, 0x12,         // tuw
    "BoxIcon",      0x7F, 0xFF,         // tBoxIcon (*)
    "CrossIcon",    0x80, 0xFF,         // tCrossIcon (*)
    "DotIcon",      0x81, 0xFF,         // tDotIcon (*)
    "*",            0x82, 0xFF,         // tMul
    "/",            0x83, 0xFF,         // tDiv
    "Trace",        0x84, 0xFF,         // tTrace
    "ClrDraw",      0x85, 0xFF,         // tClDrw
    "ZSandard",     0x86, 0xFF,         // tZoomStd
    "ZTrig",        0x87, 0xFF,         // tZoomtrg
    "ZBox",         0x88, 0xFF,         // tZoomBox
    "Zoom In",      0x89, 0xFF,         // tZoomIn
    "Zoom Out",     0x8A, 0xFF,         // tZoomOut
    "ZSquare",      0x8B, 0xFF,         // tZoomSqr
    "ZInteger",     0x8C, 0xFF,         // tZoomInt (?) - could be ZInterval
    "ZPrevious",    0x8D, 0xFF,         // tZoomPrev
    "ZDecimal",     0x8E, 0xFF,         // tZoomDec
    "ZoomStat",     0x8F, 0xFF,         // tZoomStat
    "ZoomRcl",      0x90, 0xFF,         // tUsrZm
    "PrtScrn",      0x91, 0xFF,         // tPrtScrn (*)
    "ZoomSto",      0x92, 0xFF,         // tZoomSto
    "Text(",        0x93, 0xFF,         // tText
    " nPr ",        0x94, 0xFF,         // tnPr
    " nCr ",        0x95, 0xFF,         // tnCr
    "FnOn ",        0x96, 0xFF,         // tYOn
    "FnOff ",       0x97, 0xFF,         // tYOff
    "StorePic ",    0x98, 0xFF,            // tStPic
    "RecallPic ",   0x99, 0xFF,            // tRcPic
    "StoreGDB ",    0x9A, 0xFF,            // tStoDB
    "RecallGDB ",   0x9B, 0xFF,            // tRclDB
    "Line(",        0x9C, 0xFF,            // tLine
    "Vertical ",    0x9D, 0xFF,            // tVert
    "Pt-On(",       0x9E, 0xFF,            // tPtOn
    "Pt-Off(",      0x9F, 0xFF,            // tPtOff
    "Pt-Change(",   0xA0, 0xFF,            // tPtChg
    "Pxl-On(",      0xA1, 0xFF,            // tPXOn
    "Pxl-Off(",     0xA2, 0xFF,            // tPXOff
    "Pxl-Change(",  0xA3, 0xFF,            // tPXChg
    "Shade(",       0xA4, 0xFF,            // tShade
    "Circle(",      0xA5, 0xFF,            // tCircl
    "Horizontal ",  0xA6, 0xFF,            // tHorz
    "Tangent(",     0xA7, 0xFF,            // tTanLn
    "DrawInv ",     0xA8, 0xFF,            // tDrInv
    "DrawF ",       0xA9, 0xFF,            // tDrawF
    
    "Str1",         0xAA, 0x00,         // tStr1
    "Str2",         0xAA, 0x01,         // tStr2
    "Str3",         0xAA, 0x02,         // tStr3
    "Str4",         0xAA, 0x03,         // tStr4
    "Str5",         0xAA, 0x04,         // tStr5
    "Str6",         0xAA, 0x05,         // tStr6
    "Str7",         0xAA, 0x06,         // tStr7
    "Str8",         0xAA, 0x07,         // tStr8
    "Str9",         0xAA, 0x08,         // tStr9
    "Str0",         0xAA, 0x09,         // tStr0
        
    "rand",         0xAB, 0xFF,            // tRand
    "pi",           0xAC, 0xFF,            // tPi
    "getKey",       0xAD, 0xFF,            // tGetKey
    "'",            0xAE, 0xFF,            // tAPost
    "?",            0xAF, 0xFF,            // tQuest
    "-",            0xB0, 0xFF,            // tChs
    "int(",         0xB1, 0xFF,            // tInt
    "abs(",         0xB2, 0xFF,            // tAbs
    "det(",         0xB3, 0xFF,            // tDet
    "identity(",    0xB4, 0xFF,            // tIdent
    "dim(",         0xB5, 0xFF,            // tDim
    "sum(",         0xB6, 0xFF,            // tSum
    "prod(",        0xB7, 0xFF,            // tProd
    "not(",         0xB8, 0xFF,            // tNot
    "iPart(",       0xB9, 0xFF,            // tIPart
    "fPart(",       0xBA, 0xFF,            // tFPart
    
    "npv(",         0xBB, 0x00,         // tFinNPV
    "irr(",         0xBB, 0x01,         // tFinIRR
    "bal(",         0xBB, 0x02,         // tFinBAL
    "SPrn(",        0xBB, 0x03,         // tFinPRN
    "SInt(",        0xBB, 0x04,         // tFinINT
    ">Nom(",        0xBB, 0x05,         // tFinToNom
    ">Eff(",        0xBB, 0x06,         // tFinToEff
    "dbd(",         0xBB, 0x07,         // tFinDBD
    "lcm(",         0xBB, 0x08,         // tLCM
    "gcd(",         0xBB, 0x09,         // tGCD
    "randInt(",     0xBB, 0x0A,         // tRandInt
    "randBin(",     0xBB, 0x0B,         // tRandBin
    "sub(",         0xBB, 0x0C,         // tSubStrng
    "stdDev(",      0xBB, 0x0D,         // tStdDev
    "variance(",    0xBB, 0x0E,         // tVariance
    "inString(",    0xBB, 0x0F,         // tInStrng
    "DNormal",     0xBB, 0x10,          // tDNormal (?)
    "invNormal",    0xBB, 0x11,         // tInvNormal
    "DT",          0xBB, 0x12,          // tDT (?)
    "ײ",           0xBB, 0x13,         // tChI (*)
    "DF",           0xBB, 0x14,         // tDF (*)
    "binompdf(",    0xBB, 0x15,         // tBINPDF
    "binomcdf(",    0xBB, 0x16,         // tBINCDF
    "poissonpdf(",  0xBB, 0x17,         // tPOIPDF
    "poissoncdf(",  0xBB, 0x18,         // tPOICDF
    "geometpdf(",   0xBB, 0x19,         // tGEOPDF
    "geometcdf(",   0xBB, 0x1A,         // tGEOCDF
    "normalpdf(",   0xBB, 0x1B,         // tNormalPDF
    "tcdf(",        0xBB, 0x1C,         // tTPDF (?)
    "ײpdf(",       0xBB, 0x1D,         // tChiPDF
    "Fcdf(",        0xBB, 0x1E,         // tFPDF (?)
    "randNorm(",    0xBB, 0x1F,         // tRandNorm
    "FinFPMT",      0xBB, 0x20,         // tFinFPMT
    "FinFI",        0xBB, 0x21,         // tFinFI
    "FinFPV",       0xBB, 0x22,         // tFinFPV
    "FinFN",        0xBB, 0x23,         // tFinFN
    "FinFFV",       0xBB, 0x24,         // tFinFFV
    "conj(",        0xBB, 0x25,         // tConj
    "real(",        0xBB, 0x26,         // tReal
    "imag(",        0xBB, 0x27,         // tImag
    "angle(",       0xBB, 0x28,         // tAngle
    "cumSum(",      0xBB, 0x29,         // tCumSum
    "expr(",        0xBB, 0x2A,         // tExpr
    "length(",      0xBB, 0x2B,         // tLength
    "DeltaList(",   0xBB, 0x2C,         // tDeltaLst
    "ref(",         0xBB, 0x2D,         // tRef
    "rref(",        0xBB, 0x2E,         // tRRef
    ">Rect(",       0xBB, 0x2F,         // tToRect
    ">Polar(",      0xBB, 0x30,         // tToPolar
    "Conste",      0xBB, 0x31,          // tConste (?)
    "SinReg ",      0xBB, 0x32,         // tSinReg
    "Logistic ",    0xBB, 0x33,         // tLogistic
    "LinRegTTest ", 0xBB, 0x34,         // tLinRegTTest
    "ShadeNorm(",   0xBB, 0x35,         // tShadeNorm
    "Shade_t(",     0xBB, 0x36,         // tShadeT
    "Shadeײ(",     0xBB, 0x37,         // tShadeChi
    "ShadeF(",      0xBB, 0x38,         // tShadeF
    "Matr>list(",   0xBB, 0x39,         // tMatToLst
    "List>matr(",   0xBB, 0x3A,         // tLstToMat
    "Z-Test(",      0xBB, 0x3B,         // tZTest
    "T-Test(",      0xBB, 0x3C,         // tTTest
    "2-SampZTest(", 0xBB, 0x3D,         // t2SampZTest
    "1-PropZInt(",  0xBB, 0x3E,         // t1PropZInt
    "2-PropZInt(",  0xBB, 0x3F,         // t2PropZInt
    "ײ-Test(",     0xBB, 0x40,         // tChiTest
    "ZInteger ",    0xBB, 0x41,         // tZIntVal
    "2-SampZInt(",  0xBB, 0x42,         // t2SampZInt
    "1-PropZInt(",  0xBB, 0x43,         // t1PropZInt
    "2-PropZInt(",  0xBB, 0x44,         // t2PropZInt
    "GraphStyle(",  0xBB, 0x45,         // tGraphStyle
    "2-SampTTest ", 0xBB, 0x46,         // t2SampTTest
    "2-SampFTest ", 0xBB, 0x47,         // t2SampFTest
    "TInterval ",   0xBB, 0x48,         // tTIntVal
    "2-SampTInt ",  0xBB, 0x49,         // t2SampTInt
    "SetUpEditor ", 0xBB, 0x4A,         // tSetupLst
    "Pmt_End",      0xBB, 0x4B,         // tFinPMTend
    "Pmt_Beg",      0xBB, 0x4C,         // tFinPMTbeg
    "Real",         0xBB, 0x4D,         // tRealM
    "Polar",        0xBB, 0x4E,         // tPolarM
    "Rect",         0xBB, 0x4F,         // tRectM (?)
    "ExprOn",       0xBB, 0x50,         // tExprOn
    "ExprOff",      0xBB, 0x51,         // tExprOff
    "ClrAllLists",  0xBB, 0x52,         // tClrAllLst
    "GetCalc(",     0xBB, 0x53,         // tGetCalc
    "DelVar ",      0xBB, 0x54,         // tDelVar
    "Equ>String(",  0xBB, 0x55,         // tEquToStrng
    "String>Equ(",  0xBB, 0x56,         // tStrngToEqu
    "DelLast ",     0xBB, 0x57,         // tDelLast (?)
    "Select(",      0xBB, 0x58,         // tSelect
    "ANOVA(",       0xBB, 0x59,         // tANOVA
    "ModBoxplot",   0xBB, 0x5A,         // tModBox
    "NormProbPlot", 0xBB, 0x5B,         // tNormProb
    "MGT",         0xBB, 0x64,          // tMGT (?)
    "ZoomFit",      0xBB, 0x65,         // tZFit
    "DiagnosticOn", 0xBB, 0x66,         // tDiag_on
    "DiagnosticOff",0xBB, 0x67,         // tDiag_off
    "Archive ",     0xBB, 0x68,         // tArchive
    "UnArchive ",   0xBB, 0x69,         // tUnarchive
    "Asm(",         0xBB, 0x6A,         // tasm
    "AsmComp(",     0xBB, 0x6B,         // tasmComp
    "AsmPrgm(",     0xBB, 0x6C,         // tasmPrgm
    "AsmCmp",       0xBB, 0x6D,         // tasmCmp (?)
    "",            0xBB, 0x6E,         // tLcapAAcute
    "",            0xBB, 0x6F,         // tLcapAGrave
    "",            0xBB, 0x70,         // tLcapACaret
    "",            0xBB, 0x71,         // tLcapADier 
    "",            0xBB, 0x72,         // tLaAcute
    "",            0xBB, 0x73,         // tLaGrave
    "",            0xBB, 0x74,         // tLaCaret
    "",            0xBB, 0x75,         // tLaDier
    "",            0xBB, 0x76,         // tLcapEAcute
    "",            0xBB, 0x77,         // tLcapEGrave
    "",            0xBB, 0x78,         // tLcapECaret
    "",            0xBB, 0x79,         // tLcapEDier
    "",            0xBB, 0x7A,         // tLeAcute
    "",            0xBB, 0x7B,         // tLeGrave
    "",            0xBB, 0x7C,         // tLeCaret
    "",            0xBB, 0x7D,         // tLeDier
    "",            0xBB, 0x7F,         // tLcapIGrave
    "",            0xBB, 0x80,         // tLcapICaret
    "",            0xBB, 0x81,         // tLcapIDier
    "",            0xBB, 0x82,         // tLiAcute
    "",            0xBB, 0x83,         // tLiGrave
    "",            0xBB, 0x84,         // tLiCaret
    "",            0xBB, 0x85,         // tLiDier
    "",            0xBB, 0x86,         // tLcapOAcute
    "",            0xBB, 0x87,         // tLcapOGrave
    "",            0xBB, 0x88,         // tLcapOCaret
    "",            0xBB, 0x89,         // tLcapODier
    "",            0xBB, 0x8A,         // tLoAcute
    "",            0xBB, 0x8B,         // tLoGrave
    "",            0xBB, 0x8C,         // tLoCaret
    "",            0xBB, 0x8D,         // tLoDier
    "",            0xBB, 0x8E,         // tLcapUAcute
    "",            0xBB, 0x8F,         // tLcapUGrave
    "",            0xBB, 0x90,         // tLcapUCaret
    "",            0xBB, 0x91,         // tLcapUDier
    "",            0xBB, 0x92,         // tLuAcute
    "",            0xBB, 0x93,         // tLuGrave
    "",            0xBB, 0x94,         // tLuCaret
    "",            0xBB, 0x95,         // tLuDier
    "",            0xBB, 0x96,         // tLcapCCed
    "",            0xBB, 0x97,         // tLcCed
    "",            0xBB, 0x98,         // tLcapNTilde
    "",            0xBB, 0x99,         // tLnTilde
    "",            0xBB, 0x9A,         // tLaccent
    "`",            0xBB, 0x9B,         // tLgrave
    "",            0xBB, 0x9C,         // tLdieresis
    "",            0xBB, 0x9D,         // tLquesDown
    "",            0xBB, 0x9E,         // tLexclamDown
    /* 0x9F - 0xAF are letters of the Greek alphabet;
       Plain ASCII does not support the Greek alphabet */
    "a",            0xBB, 0xB0,         // tLa
    "b",            0xBB, 0xB1,         // tLb
    "c",            0xBB, 0xB2,         // tLc
    "d",            0xBB, 0xB3,         // tLd
    "e",            0xBB, 0xB4,         // tLsmalle
    "f",            0xBB, 0xB5,         // tLf
    "g",            0xBB, 0xB6,         // tLsmallg
    "h",            0xBB, 0xB7,         // tLh
    "i",            0xBB, 0xB8,         // tLi
    "j",            0xBB, 0xB9,         // tLj
    "k",            0xBB, 0xBA,         // tLk
    "l",            0xBB, 0xBC,         // tLl
    "m",            0xBB, 0xBD,         // tLm
    "n",            0xBB, 0xBE,         // tLn
    "o",            0xBB, 0xBF,         // tLo
    "p",            0xBB, 0xC0,         // tLp
    "q",            0xBB, 0xC1,         // tLq
    "r",            0xBB, 0xC2,         // tLsmallr
    "s",            0xBB, 0xC3,         // tLs
    "t",            0xBB, 0xC4,         // tLsmallt
    "u",            0xBB, 0xC5,         // tLu
    "v",            0xBB, 0xC6,         // tLv
    "w",            0xBB, 0xC7,         // tLw
    "x",            0xBB, 0xC8,         // tLx
    "y",            0xBB, 0xC9,         // tLy
    "z",            0xBB, 0xCA,         // tLz
    /* 0xCB and 0xCC are letters of the Greek alphabet and
       thus not implemented (see above) */
    "",            0xBB, 0xCD,         // tCapIAcute
    "GarbageCollect",0xBB,0xCE,         // tGarbagec
    "~",            0xBB, 0xCF,         // tTilde
    "tReserved",    0xBB, 0xD0,         // tReserved
    "@",            0xBB, 0xD1,         // tAtSign
    "#",            0xBB, 0xD2,         // tPound (?)
    "$",            0xBB, 0xD3,         // tDollar
    "&",            0xBB, 0xD4,         // tAmpersand
    "`",            0xBB, 0xD5,         // tBackQuote
    ";",            0xBB, 0xD6,         // tSemicolon
    "\\",           0xBB, 0xD7,         // tBackSlash
    "|",            0xBB, 0xD8,         // tVertSlash
    "_",            0xBB, 0xD9,         // tUnderscore
    "%",            0xBB, 0xDA,         // tPercent
    
    "sqrt(",        0xBC, 0xFF,            // tSqrt
    "cubrt(",       0xBD, 0xFF,            // tCubRt
    "ln(",          0xBE, 0xFF,            // tLn
    "Exp",         0xBF, 0xFF,             // tExp (*)
    "log(",         0xC0, 0xFF,            // tLog
    "ALog",        0xC1, 0xFF,             // tALog (*)
    "sin(",         0xC2, 0xFF,            // tSin
    "sin^-1(",      0xC3, 0xFF,            // tASin
    "arcsin(",      0xC3, 0xFF,            // tASin
    "cos(",         0xC4, 0xFF,            // tCos
    "cos^-1(",      0xC5, 0xFF,            // tACos
    "arccos(",      0xC5, 0xFF,            // tACos
    "tan(",         0xC6, 0xFF,            // tTan
    "tan^-1(",      0xC7, 0xFF,            // tATan
    "arctan(",      0xC7, 0xFF,            // tATan
    "sinh(",        0xC8, 0xFF,            // tSin
    "sinh^-1(",     0xC9, 0xFF,            // tASin
    "arcsinh(",     0xC9, 0xFF,            // tASin
    "cosh(",        0xCA, 0xFF,            // tCos
    "cosh^-1(",     0xCB, 0xFF,            // tACos
    "arccosh(",     0xCB, 0xFF,            // tACos
    "tanh(",        0xCC, 0xFF,            // tTan
    "tanh^-1(",     0xCD, 0xFF,            // tATan
    "arctanh(",     0xCD, 0xFF,            // tATan
    "If ",          0xCE, 0xFF,            // tIf
    "Then",         0xCF, 0xFF,            // tThen
    "Else",         0xD0, 0xFF,            // tElse
    "While ",       0xD1, 0xFF,            // tWhile
    "Repeat ",      0xD2, 0xFF,            // tRepeat
    "For(",         0xD3, 0xFF,            // tFor
    "End",          0xD4, 0xFF,            // tEnd
    "Return",       0xD5, 0xFF,            // tReturn
    "Lbl ",         0xD6, 0xFF,            // tLbl
    "Goto ",        0xD7, 0xFF,            // tGoto
    "Pause ",       0xD8, 0xFF,            // tPause
    "Stop",         0xD9, 0xFF,            // tStop
    "IS>(",         0xDA, 0xFF,            // tISG
    "DS<(",         0xDB, 0xFF,            // tDSL
    "Input ",       0xDC, 0xFF,            // tInput
    "Prompt ",      0xDD, 0xFF,            // tPrompt
    "Disp ",        0xDE, 0xFF,            // tDisp
    "DispGraph",    0xDF, 0xFF,            // tDispG
    "Output(",      0xE0, 0xFF,            // tOutput
    "ClrHome",      0xE1, 0xFF,            // tClLCD
    "Fill(",        0xE2, 0xFF,            // tConst
    "SortA(",       0xE3, 0xFF,            // tSortA
    "SortD(",       0xE4, 0xFF,            // tSortD
    "DispTable",    0xE5, 0xFF,            // tDispTab
    "Menu(",        0xE6, 0xFF,            // tMenu
    "Send(",        0xE7, 0xFF,            // tSendMBL
    "Get(",         0xE8, 0xFF,            // tGetMBL
    "PlotsOn",      0xE9, 0xFF,            // tPlotOn
    "PlotsOff",     0xEA, 0xFF,            // tPlotOff
    "L",            0xEB, 0xFF,            // tListName
    "Plot1(",       0xEC, 0xFF,            // tPlot1
    "Plot2(",       0xED, 0xFF,            // tPlot2
    "Plot3(",       0xEE, 0xFF,            // tPlot3
    
    /* extra TI-84+ tokens */
    "setDate(",     0xEF, 0x00,            // tsetDate
    "setDtFmt(",    0xEF, 0x03,            // tsetDtFmt
    "setTime(",     0xEF, 0x01,            // tsetTime
    "setTmFmt(",    0xEF, 0x04,            // tsetTmFmt
    "startTmr",     0xEF, 0x0B,            // tstartTmr
    "checkTmr(",    0xEF, 0x02,            // tcheckTmr
    "ClockOff",     0xEF, 0x0F,            // tclockOff
    "ClockOn",      0xEF, 0x10,            // tclockOn
    "dayOfWk(",     0xEF, 0x06,            // tdayofwk
    "getDate",      0xEF, 0x09,            // tgetDate
    "getDtFmt",     0xEF, 0x0C,            // tgetDtFmt
    "getDtStr(",    0xEF, 0x07,            // tgetDtStr
    "getTime",      0xEF, 0x0A,            // tgetTime
    "getTmFmt",     0xEF, 0x0D,            // tgetTmFmt
    "getTmStr(",    0xEF, 0x08,            // tgetTmStr
    "isClockOn",    0xEF, 0x0E,            // tisClockOn (?)
    "???",          0xEF, 0x05,            // (??)
    
    "^",            0xF0, 0xFF,            // tPower
    "XRoot",        0xF1, 0xFF,             // tXRoot (*)
    "OneVar ",      0xF2, 0xFF,            // tOneVar (?)
    "TwoVar ",      0xF3, 0xFF,            // tTwoVar (?)
    "LinReg(a+bx) ",0xF4, 0xFF,            // tLR
    "ExpReg ",      0xF5, 0xFF,            // tLRExp
    "LnReg ",       0xF6, 0xFF,            // tLRLn
    "PwrReg ",      0xF7, 0xFF,            // tLRPwr
    "Med-Med ",     0xF8, 0xFF,            // tMedMed
    "QuadReg ",     0xF9, 0xFF,            // tQuad
    "ClrList",      0xFA, 0xFF,            // tClrLst
    "ClrTable",     0xFB, 0xFF,            // tClrTbl
    "Histogram",    0xFC, 0xFF,            // tHist
    "xyLine",       0xFD, 0xFF,            // txyLine
    "Scatter",      0xFE, 0xFF,            // tScatter
    "LinReg(ax+b) ",0xFF, 0xFF,            // tLR1
    0, 0, 0
};

/* Last Edit: Mar. 25th, 2006 */
